@@ -117,18 +117,18 @@ class DatatapProxy(base.BaseProxy):
         ), "'read-only' parameter must be 'True' or 'False'"
 
         base.get_client().datatap.create_hdfs_with_kerberos(
-            name,
-            description,
-            path_from_endpoint,
-            kdc_data_host,
-            kdc_data_port,
-            realm,
-            client_principal,
-            browse_only,
-            host,
-            keytab,
-            backup_host,
-            type,
-            port,
-            read_only,
+            name=name,
+            description=description,
+            path_from_endpoint=path_from_endpoint,
+            kdc_data_host=kdc_data_host,
+            kdc_data_port=kdc_data_port,
+            realm=realm,
+            client_principal=client_principal,
+            browse_only=browse_only,
+            host=host,
+            keytab=keytab,
+            backup_host=backup_host,
+            type=type,
+            port=port,
+            read_only=read_only,
         )
